==> pf_slack-2.0.x-dev.tar.gz: pf_slack/src/Form/Settings.php <==
<?php

namespace Drupal\pf_slack\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\push_framework\Form\Settings as FrameworkSettings;

/**
 * Configure Push Framework Slack settings.
 */
class Settings extends FrameworkSettings {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'pf_slack_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['pf_slack.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['slack_details'] = [
      '#type' => 'container',
      '#states' => [
        'visible' => [
          ':input[name="active"]' => ['checked' => TRUE],
        ],
      ],
    ];
    $form['slack_details']['url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Webhook URL'),
      '#default_value' => $this->pluginConfig->get('url'),
      '#description' => $this->t('Provide the webhook URL of your Slack instance, you can create one by <a href="https://my.slack.com/services/new/incoming-webhook">following this link</a>.'),
    ];
    $form['slack_details']['channel_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Channel ID'),
      '#default_value' => $this->pluginConfig->get('channel_id'),
      '#description' => $this->t('Example <em>#general</em>.'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->pluginConfig
      ->set('url', $form_state->getValue('url'))
      ->set('channel_id', $form_state->getValue('channel_id'));
    parent::submitForm($form, $form_state);
  }

}

==> pf_slack-2.1.x-dev.tar.gz: pf_slack/src/Form/Settings.php <==
<?php

namespace Drupal\pf_slack\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\push_framework\Form\Settings as FrameworkSettings;

/**
 * Configure Push Framework Slack settings.
 */
class Settings extends FrameworkSettings {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'pf_slack_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['pf_slack.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['slack_details'] = [
      '#type' => 'container',
      '#states' => [
        'visible' => [
          ':input[name="active"]' => ['checked' => TRUE],
        ],
      ],
    ];
    $form['slack_details']['token'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Token'),
      '#default_value' => $this->pluginConfig->get('token'),
      '#description' => $this->t('Provide the token of your Slack integration, you can create one by <a href="https://my.slack.com/services/new/incoming-webhook">following this link</a>.'),
    ];
    $form['slack_details']['username'] = [
      '#type' => 'textfield',
      '#title' => $this->t('User name'),
      '#default_value' => $this->pluginConfig->get('username'),
      '#description' => $this->t('The name of the user that appears as the sender of the message.'),
    ];
    $form['slack_details']['channel_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Channel ID'),
      '#default_value' => $this->pluginConfig->get('channel_id'),
      '#description' => $this->t('Example <em>#general</em>.'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->pluginConfig
      ->set('token', $form_state->getValue('token'))
      ->set('username', $form_state->getValue('username'))
      ->set('channel_id', $form_state->getValue('channel_id'));
    parent::submitForm($form, $form_state);
  }

}
